#!/usr/bin/env python3
from setuptools import setup

PLUGIN_ENTRY_POINT = 'ovos-tts-plugin-server = ovos_tts_plugin_server:OVOSServerTTS'
CONFIG_ENTRY_POINT = 'ovos-tts-plugin-server.config = ovos_tts_plugin_server:OVOSServerTTSConfig'


setup(
    name='ovos-tts-plugin-server',
    version='0.0.2a1',
    description='ovos tts server plugin for mycroft',
    url='https://github.com/OpenVoiceOS/ovos-tts-server-plugin',
    author='JarbasAi',
    author_email='jarbasai@mailfence.com',
    license='Apache-2.0',
    packages=['ovos_tts_plugin_server'],
    install_requires=['ovos-plugin-manager>=0.0.5'],
    zip_safe=True,
    include_package_data=True,
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Text Processing :: Linguistic',
        'License :: OSI Approved :: Apache Software License',

        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.0',
        'Programming Language :: Python :: 3.1',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    keywords='mycroft OpenVoiceOS OVOS plugin tts',
    entry_points={'mycroft.plugin.tts': PLUGIN_ENTRY_POINT,
                  'mycroft.plugin.tts.config': CONFIG_ENTRY_POINT}
)



import requests
from ovos_plugin_manager.templates.tts import TTS, TTSValidator


class OVOSServerTTS(TTS):
    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs, audio_ext="wav",
                         validator=OVOSServerTTSValidator(self))
        self.host = self.config.get("host") or "http://0.0.0.0:9666"

    def get_tts(self, sentence, wav_file, lang=None, voice=None):
        lang = lang or self.lang
        voice = voice or self.voice
        data = requests.get(f"{self.host}/synthesize/{sentence}",
                            params={"lang": lang, "voice": voice}).content
        with open(wav_file, "wb") as f:
            f.write(data)
        return wav_file, None


class OVOSServerTTSValidator(TTSValidator):
    def __init__(self, tts):
        super(OVOSServerTTSValidator, self).__init__(tts)

    def validate_lang(self):
        pass

    def validate_connection(self):
        pass

    def get_tts_class(self):
        return OVOSServerTTS


OVOSServerTTSConfig = {}

# jarbas public demo instances
jarbas_hosted = {
    "S.A.M.": ("https://sam.jarbasai.online", "male"),
    "PicoTTS": ("https://pico.jarbasai.online", "female"),
    "Glados": ("https://glados.jarbasai.online", "female"),
    "Alan Pope [Mimic 1]": ("https://mimic.jarbasai.online", "male"),
    "R2D2": ("https://r2d2.jarbasai.online", "neutral")
}

OVOSServerTTSConfig["en-us"] = [
    {"lang": "en-us",
     "url": url,
     "gender": gender,
     "display_name": f"{display_name} (jarbasai.online)",
     "offline": False}
    for display_name, (url, gender) in jarbas_hosted.items()
]
